/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import PropTypes from 'prop-types';
import React from 'react';

import NodeListItem from './NodeListItem';

export default function NodeList({
	NodeComponent,
	nodes,
	onBlur,
	onFocus,
	role = 'group',
	tabIndex = -1,
}) {
	const rootNodeId = nodes[0] && nodes[0].id;

	if (!rootNodeId) {
		// All nodes have been filtered.
		return null;
	}

	return (
		<div
			className="lfr-treeview-node-list"
			onBlur={() => {
				if (onBlur) {
					onBlur();
				}
			}}
			onFocus={event => {
				if (onFocus) {
					onFocus(event);
				}
			}}
			role={role}
			tabIndex={tabIndex}
		>
			{nodes.map(node => (
				<NodeListItem
					key={node.id}
					node={node}
					NodeComponent={NodeComponent}
				/>
			))}
		</div>
	);
}

NodeList.propTypes = {
	NodeComponent: PropTypes.func.isRequired,
	nodes: PropTypes.arrayOf(
		PropTypes.shape({
			children: PropTypes.array,
			id: PropTypes.string.isRequired,
			name: PropTypes.string.isRequired,
		})
	).isRequired,
	onBlur: PropTypes.func,
	onFocus: PropTypes.func,
	tabIndex: PropTypes.number,
};
